
Authors
=======

* Gramazio Kohler Research `@gramaziokohler <https://github.com/gramaziokohler>`_
* Romana Rust <rust@arch.ethz.ch> `@romanarust <https://github.com/romanarust>`_
* Gonzalo Casas <casas@arch.ethz.ch> `@gonzalocasas <https://github.com/gonzalocasas>`_
* Stefana Parascho <parascho@arch.ethz.ch> `@stefanaparascho <https://github.com/stefanaparascho>`_
* David Jenny <jenny@arch.ethz.ch> `@DavidJenny <https://github.com/DavidJenny>`_
* Kathrin Dörfler <doerfler@arch.ethz.ch> `@Kathrin3010 <https://github.com/Kathrin3010>`_
* Matthias Helmreich <helmreich@arch.ethz.ch> `@mhelmrei <https://github.com/mhelmrei>`_
* Augusto Gandia <gandia@arch.ethz.ch> `@augustogandia <https://github.com/augustogandia>`_
